==> jaxx-runtime-2.2-sources.jar: jaxx/runtime/swing/renderer/DecoratorProviderListCellRenderer.java <==
/*
 * #%L
 * JAXX :: Runtime
 * 
 * $Id: DecoratorProviderListCellRenderer.java 1847 2010-04-16 12:27:48Z tchemit $
 * $HeadURL: http://svn.nuiton.org/svn/jaxx/tags/jaxx-2.2/jaxx-runtime/src/main/java/jaxx/runtime/swing/renderer/DecoratorProviderListCellRenderer.java $
 * %%
 * Copyright (C) 2008 - 2010 CodeLutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as 
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Lesser Public License for more details.
 * 
 * You should have received a copy of the GNU General Lesser Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/lgpl-3.0.html>.
 * #L%
 */
package jaxx.runtime.swing.renderer;

import jaxx.runtime.decorator.Decorator;
import jaxx.runtime.decorator.DecoratorProvider;

import javax.swing.*;
import java.awt.*;

/**
 * A {@link ListCellRenderer} which use decorators from the {@link #provider} to obtain the text to display.
 *
 * The interest of this renderer is to define a unique renderer for your application (put it in JAXXContext)
 * and then use it simply :)
 * 
 * User: chemit
 * Date: 29 oct. 2009
 * Time: 03:00:53
 * @since 2.0.0
 * @see DecoratorProvider
 */
public class DecoratorProviderListCellRenderer implements ListCellRenderer {

    /**
     * Delegate cell renderer
     */
    protected ListCellRenderer delegate;

    /**
     * provider of decorators
     */
    protected DecoratorProvider provider;

    public DecoratorProviderListCellRenderer(DecoratorProvider provider) {
        this(new DefaultListCellRenderer(), provider);
    }

    public DecoratorProviderListCellRenderer(ListCellRenderer delegate, DecoratorProvider provider) {
        this.delegate = delegate;
        this.provider = provider;
    }

    @Override
    public Component getListCellRendererComponent(JList list, Object value, int index, boolean isSelected, boolean cellHasFocus) {
        if (value != null) {
            Decorator<?> decorator = provider.getDecorator(value);

            if (decorator != null) {
                value = decorator.toString(value);
            }
        } else {
            value = " ";
        }
        return delegate.getListCellRendererComponent(list, value, index, isSelected, cellHasFocus);
    }
}

==> jaxx-runtime-2.2.1-sources.jar: jaxx/runtime/swing/renderer/DecoratorProviderListCellRenderer.java <==
/*
 * #%L
 * JAXX :: Runtime
 * 
 * $Id: DecoratorProviderListCellRenderer.java 2086 2010-09-11 19:39:49Z tchemit $
 * $HeadURL: http://svn.nuiton.org/svn/jaxx/tags/jaxx-2.2.1/jaxx-runtime/src/main/java/jaxx/runtime/swing/renderer/DecoratorProviderListCellRenderer.java $
 * %%
 * Copyright (C) 2008 - 2010 CodeLutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as 
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Lesser Public License for more details.
 * 
 * You should have received a copy of the GNU General Lesser Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/lgpl-3.0.html>.
 * #L%
 */
package jaxx.runtime.swing.renderer;

import jaxx.runtime.decorator.Decorator;
import jaxx.runtime.decorator.DecoratorProvider;

import javax.swing.DefaultListCellRenderer;
import javax.swing.JList;
import javax.swing.ListCellRenderer;
import java.awt.Component;

/**
 * A {@link ListCellRenderer} which use decorators from the {@link #provider} to obtain the text to display.
 * <p/>
 * The interest of this renderer is to define a unique renderer for your application (put it in JAXXContext)
 * and then use it simply :)
 * <p/>
 * User: chemit
 * Date: 29 oct. 2009
 * Time: 03:00:53
 *
 * @see DecoratorProvider
 * @since 2.0.0
 */
public class DecoratorProviderListCellRenderer implements ListCellRenderer {

    /** Delegate cell renderer */
    protected ListCellRenderer delegate;

    /** provider of decorators */
    protected DecoratorProvider provider;

    public DecoratorProviderListCellRenderer(DecoratorProvider provider) {
        this(new DefaultListCellRenderer(), provider);
    }

    public DecoratorProviderListCellRenderer(ListCellRenderer delegate, DecoratorProvider provider) {
        this.delegate = delegate;
        this.provider = provider;
    }

    @Override
    public Component getListCellRendererComponent(JList list, Object value, int index, boolean isSelected, boolean cellHasFocus) {
        if (value != null) {
            Decorator<?> decorator = provider.getDecorator(value);

            if (decorator != null) {
                value = decorator.toString(value);
            }
        } else {
            value = " ";
        }
        return delegate.getListCellRendererComponent(list, value, index, isSelected, cellHasFocus);
    }
}
